Module agent

Module agent 

Traits for implementing custom SSH agents.

Agents which store no state or their state is minimal should implement the Session trait. If a more elaborate state is needed, especially one which depends on the socket making the connection then it is advisable to implement the Agent trait.

Re-exports

pub use service_binding;

Traits

Agent
Factory of sessions for the given type of sockets.
ListeningSocket
Type representing a socket that asynchronously returns a list of streams.
Session
Represents one active SSH connection.

Functions

bind
Bind to a service binding listener.
listen
Listen for connections on a given socket and use session factory to create new session for each accepted socket.