KeyConstraintExtension

Trait KeyConstraintExtension 

pub trait KeyConstraintExtension: 'static {
    const NAME: &'static str;
}
SSH agent protocol key constraint extension

Described in draft-miller-ssh-agent-14  3.2.7.3

Required Associated Constants

const NAME: &'static str

Extension name, indicating the type of the key constraint (as a UTF-8 string).

Extension names should be suffixed by the implementation domain as per RFC4251  4.2,

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl KeyConstraintExtension for RestrictDestination

Source

const NAME: &'static str = "restrict-destination-v00@openssh.com"