MessageExtension

Trait MessageExtension 

pub trait MessageExtension: 'static {
    const NAME: &'static str;
}
SSH agent protocol message extension

Described in draft-miller-ssh-agent-14  3.8

Required Associated Constants

const NAME: &'static str

Extension name, indicating the type of the message (as a UTF-8 string).

Extension names should be suffixed by the implementation domain as per RFC4251  4.2,

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl MessageExtension for QueryResponse

Source

const NAME: &'static str = "query"

Source

impl MessageExtension for SessionBind

Source

const NAME: &'static str = "session-bind@openssh.com"