pub enum PrivateCredential {
Key {
privkey: KeypairData,
comment: String,
},
Cert {
algorithm: Algorithm,
certificate: Box<Certificate>,
privkey: PrivateKeyData,
comment: String,
},
}Expand description
A container for a public / private key pair, or a certificate / private key.
When adding an identity to an agent, a user can provide either:
- A public / private key pair
- An OpenSSH certificate
This structure covers both types of identities a user may
send to an agent as part of a Request::AddIdentity message.
Variants
Key
A public/private key pair
Cert
An OpenSSH certificate